/*------------------------------------------------*/
/* 25daemon/demon.c                               */
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <sys/stat.h>
#include "pidfile.h"
#include "log.h"
#include "signals.h"

static void usage()
{
    printf("demon path_to_pid_file [log_message]\n");
}

static void printPidInfo()
{
    printf("process id = %i, session id = %i, parent id = %i\n",
           getpid(), getsid(0), getppid());
}

static int closeStandardDescriptors()
{
    close(STDIN_FILENO);
    close(STDOUT_FILENO);
    close(STDERR_FILENO);
    if (open("/dev/null", O_RDONLY) == -1) {
        perror("open 1");
        return 2;
    }
    if (open("/dev/null", O_WRONLY) == -1) {
        perror("open 2");
        return 2;
    }
    if (open("/dev/null", O_RDWR) == -1) {
        perror("open 3");
        return 2;
    }
    return 0;
}

int main(int argc, char *argv[])
{
    pid_t pid, sid;
    int ret;
    char *pidfile;
    int running = 1;
    int sighup = 0;

    if (argc < 2) {
        usage();
        return 2;
    }
    pidfile = argv[1];
    ret = openPidFile(pidfile);
    if (ret) {
        exit(ret);
    }

    printPidInfo();

    /* Forking and killing father */
    pid = fork();
    if (pid < 0) {
        perror("fork");
        exit(2);
    }
    if (pid > 0) {
        exit(0);                /* Rodičovský proces */
    }
    printPidInfo();

    umask(0);
    openLog();
    if (argc > 2) {
        writeLog("%s", argv[2]);
    }

    /* vytvoreni noveho session ID */
    sid = setsid();
    if (sid < 0) {
        perror("setsid");
        exit(2);
    }
    printPidInfo();

    /* zmena pracovniho adresare */
    if (chdir("/") < 0) {
        perror("chdir");
        exit(2);
    }

    setSignalHandlers(&running, &sighup);

    closeStandardDescriptors();

    closePidFile();

    /* Demon zacina svou praci */
    while (running) {
        if (sighup) {
            sighup = 0;
            writeLog("Načítám znovu konfiguraci.");
            continue;
        }
        writeLog("Pracuji.");
        ret = sleep(5);
        if (ret) {
            writeLog("Sleep byl přerušen o %i sec dříve.", ret);
        }
    }

    removePidFile(pidfile);
    writeLog("%s", "Končím v míru.");
    closeLog();

    return EXIT_SUCCESS;
}

/*------------------------------------------------*/
