/*------------------------------------------------*/
/* 26regexp/parse-options-pcre.c                  */

#include "parse-options-pcre.h"
#include <getopt.h>

task parseOptions(int argc, char * const argv[]) {
    int c;
    char * optstring = "+hsp:inu";
    const struct option longopts[] = {
        {"help",    no_argument, NULL, 'h'},
        {"show-options",    no_argument, NULL, 's'},
        {"pattern", required_argument, NULL, 'p'},
        {"icase",   no_argument, NULL, 'i'},
        {"newline", no_argument, NULL, 'n'},
        {"no-ucp",   no_argument, NULL, 'u'},
	{NULL, 0, NULL, 0}
    };
    task t = {false, false, false, "", "", false, false, true};

    do {
        c =  getopt_long(argc, argv, optstring, longopts, NULL);
        switch(c) {
            case -1: break;
            case '?': t.err = true; break;
            case 'h': t.help = true; break;
            case 's': t.show = true; break;
            case 'i': t.icase = true; break;
            case 'n': t.newline = true; break;
	    case 'u': t.ucp = false; break;
            case 'p': t.pattern = optarg; break;
        }
    } while(!t.err && !t.help  && c != -1);

    if(optind < argc) {
        t.string = argv[optind];
    }

    return t;
}

void printOptions(task t) {
    printf(
        "ERR:\t\t %s\n"
        "Help:\t\t %s\n"
        "Show options:\t %s\n"
        "Pattern:\t '%s'\n"
        "Search in:\t '%s'\n"
        "PCRE_CASELESS:\t %s\n"
        "PCRE_MULTILINE:\t %s\n"
        "PCRE_UCP:\t %s\n",
        t.err ? "ANO" : "NE", 
        t.help ? "ANO" : "NE", 
        t.show ? "ANO" : "NE", 
        t.pattern, 
        t.string, 
        t.icase  ? "ANO" : "NE", 
        t.newline ? "ANO" : "NE",
        t.ucp ? "ANO" : "NE"
    );
}

void printOptionsHelp() {
    printf("Použití:\n");
    printf("./regex1 -h | [-p|--pattern \"regular expression\"] [-i|--icase] [-n|--newline] [-u|--no-ucp] [\"prohledávaný řetězec\"]\n\n");
}

/*------------------------------------------------*/
