/*------------------------------------------------*/
/* 51ncurses/mouse.c                              */
#include <ncurses.h>
#include <locale.h>
#include <stdlib.h>
#include <string.h>

static void obnovTerminal()
{
    printw("Obnovuji nastavení terminálu\n");
    endwin();
}

static void initNcurses() {
    setlocale(LC_ALL, "");
    initscr();
    noecho();
    raw();
    atexit(obnovTerminal);

    if (!has_colors()) {
        fprintf(stderr, "Terminál nepodporuje barvy\n");
        exit(EXIT_FAILURE);
    }
    if (start_color() != OK) {
        fprintf(stderr, "Nepodařilo se inicializovat barvy\n");
        exit(EXIT_FAILURE);
    }
}


int main()
{
    int c;
    int released = 0, pressed = 0, clicked = 0, moved = 0;
    MEVENT event;

    initNcurses();
    curs_set(0);
    use_default_colors();

    mousemask(ALL_MOUSE_EVENTS | REPORT_MOUSE_POSITION, NULL);
    if (!has_mouse()) {
        endwin();
        fprintf(stderr, "Terminál nepodporuje myš\n");
        exit(EXIT_FAILURE);
    }

    mvprintw(23, 1, "Enter = konec programu");
    refresh();
    /* Get all the mouse events */
    keypad(stdscr, TRUE);
    while (1) {
        c = getch();
        switch (c) {
        case KEY_MOUSE:
            if (getmouse(&event) == OK) {
                if (event.bstate & REPORT_MOUSE_POSITION) {
                    moved++;
                    mvprintw(0, 1,
                         "MOUSE MOVED[%3i,%3i] %3i times.",
                         event.x, event.y, moved);
                    refresh();
                }
                if (event.bstate & BUTTON1_RELEASED) {
                    released++;
                    mvprintw(1, 1,
                         "BUTTON1_RELEASED [%3i,%3i] %3i times.",
                         event.x, event.y, released);
                    mvprintw(event.y, event.x, "*");
                    refresh();
                }
                if (event.bstate & BUTTON1_PRESSED) {
                    pressed++;
                    mvprintw(2, 1,
                         "BUTTON1_PRESSED [%3i,%3i] %3i times",
                         event.x, event.y, pressed);
                    mvprintw(event.y, event.x, "*");
                    refresh();
                }
                if (event.bstate & BUTTON1_CLICKED) {
                    clicked++;
                    mvprintw(3, 1,
                         "BUTTON1_CLICKED [%3i,%3i] %3i times",
                         event.x, event.y, clicked);
                    mvprintw(event.y, event.x, "*");
                    refresh();
                }
                if (event.bstate & BUTTON2_CLICKED)    // prostredni tlacitko
                {
                    clicked++;
                    mvprintw(4, 1,
                         "BUTTON2_CLICKED [%3i,%3i]",
                         event.x, event.y);
                    mvprintw(event.y, event.x, "I");
                    refresh();
                }
                if (event.bstate & BUTTON3_CLICKED)    // prave tlacitko
                {
                    clicked++;
                    mvprintw(5, 1,
                         "BUTTON3_CLICKED [%3i,%3i]",
                         event.x, event.y);
                    mvprintw(event.y, event.x, "@");
                    refresh();
                }
            }
            break;
        case '\n':
            endwin();
            return 0;
        }
    }
    endwin();
    return 0;
}
/*------------------------------------------------*/
