/*------------------------------------------------*/
/* 51ncurses/pad.c                                */
#include <stdio.h>
#include <ncurses.h>
#include <locale.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>

static void obnovTerminal()
{
    printw("Obnovuji nastavení terminálu\n");
    endwin();
}

static void initNcurses() {
    setlocale(LC_ALL, "");
    initscr();
    noecho();
    raw();
    atexit(obnovTerminal);

    if (!has_colors()) {
        fprintf(stderr, "Terminál nepodporuje barvy\n");
        exit(EXIT_FAILURE);
    }
    if (start_color() != OK) {
        fprintf(stderr, "Nepodařilo se inicializovat barvy\n");
        exit(EXIT_FAILURE);
    }
}

#define P_SLOUPCU 80
#define P_RADKU  120
#define WIDTH 60
#define HEIGHT 20

static void vykresliOkno(WINDOW * okno, const int radek, const int sloupcu)
{
    int i, j;
    char text[P_SLOUPCU + 1 - 4];
    for (i = 0; i < radek; i++) {
        for (j = 0; j < sloupcu; j++)
            mvwprintw(okno, i, j, "%c", ' ');
        mvwprintw(okno, i, 0, "%03i", i + 1);
    }

    FILE *f = fopen("pad.c", "r");
    i = 0;
    while (fgets(text, sizeof(text), f)) {
        text[strlen(text) - 1] = '\0';
        mvwprintw(okno, i++, 4, "%*s", strlen(text) - 1, text);
    }
    fclose(f);

}

int main(void)
{
    enum pairs { pair_stdscr = 1, pair_okno };
    int ch;
    int pminrow, pmincol;
    WINDOW *okno;

    initNcurses();
    curs_set(0);

    /* nastaveni barvy pozadi a prekresleni cele obrazovky */
    assume_default_colors(COLOR_RED, COLOR_YELLOW);
    erase();
    refresh();

    okno = newpad(P_RADKU, P_SLOUPCU);
    /* nastaveni okna */
    init_pair(pair_okno, COLOR_RED, COLOR_WHITE);
    wattrset(okno, COLOR_PAIR(pair_okno));
    vykresliOkno(okno, P_RADKU, P_SLOUPCU);
    wattron(okno, A_BOLD);
    mvprintw(0, 1, "Enter = konec, sipky = posun okna.");

    keypad(stdscr, TRUE);
    ch = '\0';
    pminrow = pmincol = 0;
    do {
        mvprintw(1, 1, "Pminrow = %3i, pmincol = %3i.", pminrow,
             pmincol);
        wnoutrefresh(stdscr);
        pnoutrefresh(okno, pminrow, pmincol, 2, 1, HEIGHT + 1, WIDTH + 0);
        doupdate();

        ch = getch();
        switch (ch) {
        case KEY_LEFT:
            if (pmincol > 0) {
                pmincol--;
            }
            break;
        case KEY_RIGHT:
            if (pmincol < P_SLOUPCU - WIDTH) {
                pmincol++;
            }
            break;
        case KEY_UP:
            if (pminrow > 0) {
                pminrow--;
            }
            break;
        case KEY_DOWN:
            if (pminrow < P_RADKU - HEIGHT) {
                pminrow++;
            }
            break;
        }
    } while (ch && ch != '\n');

    return 0;
}

/*------------------------------------------------*/
