/*------------------------------------------------*/
/* 51ncurses/window.c                             */
#include <stdio.h>
#include <ncurses.h>
#include <locale.h>
#include <stdlib.h>
#include <unistd.h>

#define O_RADKU 5
#define O_SLOUPCU 50

static void obnovTerminal()
{
    printw("Obnovuji nastavení terminálu\n");
    endwin();
}

static void initNcurses() {
    setlocale(LC_ALL, "");
    initscr();
    noecho();
    raw();
    if (!has_colors()) {
        endwin();
        fprintf(stderr, "Terminál nepodporuje barvy\n");
        exit(EXIT_FAILURE);
    }
    if (start_color() != OK) {
        endwin();
        fprintf(stderr, "Nepodařilo se inicializovat barvy\n");
        exit(EXIT_FAILURE);
    }
    atexit(obnovTerminal);
}

static void wpozadi(WINDOW * okno, const int radek, const int sloupcu)
{
    int i, j;
    for (i = 0; i < radek; i++)
        for (j = 0; j < sloupcu; j++)
            mvwprintw(okno, i, j, "%c", '.');
    wmove(okno, 0, 0);
}

int main(void)
{
    enum pairs { pair_stdscr = 1, pair_okno };
    int ch;
    int line, col;
    WINDOW *okno;

    initNcurses();
    curs_set(0);

    /* nastaveni barvy pozadi a prekresleni cele obrazovky */
    assume_default_colors(COLOR_RED, COLOR_YELLOW);
    erase();
    refresh();

    line = LINES / 2 - 3;
    col = COLS / 2 - 25;
    okno = newwin(O_RADKU, O_SLOUPCU, line, col);

    /* nastaveni okna */
    init_pair(pair_okno, COLOR_RED, COLOR_WHITE);
    wattrset(okno, COLOR_PAIR(pair_okno));
    wpozadi(okno, O_RADKU, O_SLOUPCU);
    //box(okno,'|','-');
    box(okno, ACS_VLINE, ACS_HLINE);
    wprintw(okno, "Nové okno");
    mvwprintw(okno, 2, 2, "Ahoj světe!");
    wattron(okno, A_BOLD);
    mvwprintw(okno, 4, 1, " Enter = konec, c = clear, sipky = posun okna ");

    keypad(stdscr, TRUE);
    ch = '\0';
    do {
        wrefresh(okno);
        ch = getch();
        switch (ch) {
        case KEY_LEFT:
            if (col > 0) {
                col--;
                mvwin(okno, line, col);
            }
            break;
        case KEY_RIGHT:
            col++;
            mvwin(okno, line, col);
            break;
        case KEY_UP:
            if (line > 0) {
                line--;
                mvwin(okno, line, col);
            }
            break;
        case KEY_DOWN:
            line++;
            mvwin(okno, line, col);
            break;
        case 'c':
            touchwin(stdscr);
            wrefresh(stdscr);
            break;
        }
    } while (ch && ch != '\n');

    return 0;
}

/*------------------------------------------------*/
